Utilities
=================

.. currentmodule:: pynrc

.. autosummary::
   :toctree: _autosummary
   :template: custom-module-template.rst
   :recursive:
   
   maths.coords
   maths.image_manip
   nrc_utils
   opds
   nb_funcs
   logging_utils

